@@ -1,74 +1,71 @@
 """
 Generated using https://signald.org/protocol.json
-Version: '0.20.0-7-7d9179fd'
+Version: '0.21.1'=
 """
 
-from dataclasses import dataclass, field
-import typing as typing_  # avoid conflict with the typing method
-
-from aiosignald.error import SignaldException
-from aiosignald.generated import *
-
-
-class DuplicateMessageError(SignaldException):
-    timestamp: int = None
-    message: str = None
+from .error import SignaldException
+from .generated import *
 
 
 class UntrustedIdentityError(SignaldException):
-    identifier: str = None
-    message: str = None
-    identity_key: "IdentityKeyv1" = None
-
-
-class ProtocolInvalidMessageError(SignaldException):
-    sender: str = None
-    timestamp: int = None
-    message: str = None
-    sender_device: int = None
-    content_hint: int = None
-    group_id: str = None
-
-
-class ProtocolInvalidKeyIdError(SignaldException):
-    sender: str = None
-    timestamp: int = None
-    message: str = None
-    sender_device: int = None
-    content_hint: int = None
-    group_id: str = None
+    identifier: str
+    message: str
+    identity_key: "IdentityKeyv1"
 
 
 class ProtocolNoSessionError(SignaldException):
-    sender: str = None
-    timestamp: int = None
-    message: str = None
-    sender_device: int = None
-    content_hint: int = None
-    group_id: str = None
+    sender: str
+    timestamp: int
+    message: str
+    sender_device: int
+    content_hint: int
+    group_id: str
+
+
+class DuplicateMessageError(SignaldException):
+    timestamp: int
+    message: str
+
+
+class ProtocolInvalidMessageError(SignaldException):
+    sender: str
+    timestamp: int
+    message: str
+    sender_device: int
+    content_hint: int
+    group_id: str
+
+
+class ProtocolInvalidKeyIdError(SignaldException):
+    sender: str
+    timestamp: int
+    message: str
+    sender_device: int
+    content_hint: int
+    group_id: str
 
 
 class NoSuchAccountError(SignaldException):
-    account: str = None
-    message: str = None
+    account: str
+    message: str
 
 
 class ServerNotFoundError(SignaldException):
-    uuid: str = None
-    message: str = None
+    uuid: str
+    message: str
 
 
 class InvalidProxyError(SignaldException):
-    message: str = None
+    message: str
 
 
 class NoSendPermissionError(SignaldException):
-    message: str = None
+    message: str
 
 
 class InvalidAttachmentError(SignaldException):
-    filename: str = None
-    message: str = None
+    filename: str
+    message: str
 
 
 class InternalError(SignaldException):
@@ -76,29 +73,29 @@ class InternalError(SignaldException):
     an internal error in signald has occurred. typically these are things that "should never happen" such as issues saving to the local disk, but it is also the default error type and may catch some things that should have their own error type. If you find tht your code is depending on the exception list for any particular behavior, please file an issue so we can pull those errors out to a separate error type: https://gitlab.com/signald/signald/-/issues/new
     """
 
-    exceptions: typing_.List[str] = field(default_factory=list)
-    message: str = None
+    exceptions: list[str]
+    message: str
 
 
 class InvalidRequestError(SignaldException):
-    message: str = None
+    message: str
 
 
 class UnknownGroupError(SignaldException):
-    message: str = None
+    message: str
 
 
 class RateLimitError(SignaldException):
-    message: str = None
+    message: str
 
 
 class InvalidRecipientError(SignaldException):
-    message: str = None
+    message: str
 
 
 class AttachmentTooLargeError(SignaldException):
-    filename: str = None
-    message: str = None
+    filename: str
+    message: str
 
 
 class AuthorizationFailedError(SignaldException):
@@ -106,20 +103,27 @@ class AuthorizationFailedError(SignaldException):
     Indicates the server rejected our credentials or a failed group update. Typically means the linked device was removed by the primary device, or that the account was re-registered. For group updates, this can indicate that we lack permissions.
     """
 
-    message: str = None
+    message: str
 
 
 class SQLError(SignaldException):
-    message: str = None
+    message: str
+
+
+class ProofRequiredError(SignaldException):
+    token: str
+    options: list[str]
+    message: str
+    retry_after: int
 
 
 class UnregisteredUserError(SignaldException):
-    message: str = None
-    e164_number: str = None
+    message: str
+    e164_number: str
 
 
 class OwnProfileKeyDoesNotExistError(SignaldException):
-    message: str = None
+    message: str
 
 
 class GroupPatchNotAcceptedError(SignaldException):
@@ -127,23 +131,23 @@ class GroupPatchNotAcceptedError(SignaldException):
     Indicates the server rejected our group update. This can be due to errors such as trying to add a user that's already in the group.
     """
 
-    message: str = None
+    message: str
 
 
 class GroupVerificationError(SignaldException):
-    message: str = None
+    message: str
 
 
 class InvalidGroupStateError(SignaldException):
-    message: str = None
+    message: str
 
 
 class InvalidInviteURIError(SignaldException):
-    message: str = None
+    message: str
 
 
 class GroupNotActiveError(SignaldException):
-    message: str = None
+    message: str
 
 
 class UnsupportedGroupError(SignaldException):
@@ -151,74 +155,114 @@ class UnsupportedGroupError(SignaldException):
     returned in response to use v1 groups, which are no longer supported
     """
 
-    message: str = None
+    message: str
 
 
 class InvalidBase64Error(SignaldException):
-    message: str = None
-
-
-class ProofRequiredError(SignaldException):
-    token: str = None
-    options: typing_.List[str] = field(default_factory=list)
-    message: str = None
-    retry_after: int = None
+    message: str
 
 
 class ProfileUnavailableError(SignaldException):
-    message: str = None
+    message: str
 
 
 class NoKnownUUIDError(SignaldException):
-    message: str = None
+    message: str
 
 
 class NoSuchSessionError(SignaldException):
-    message: str = None
+    message: str
 
 
 class UserAlreadyExistsError(SignaldException):
-    uuid: str = None
-    message: str = None
+    uuid: str
+    message: str
 
 
 class ScanTimeoutError(SignaldException):
-    message: str = None
+    message: str
 
 
 class CaptchaRequiredError(SignaldException):
-    more: str = None
-    message: str = None
+    more: str
+    message: str
 
 
 class AccountHasNoKeysError(SignaldException):
-    message: str = None
+    message: str
 
 
 class AccountAlreadyVerifiedError(SignaldException):
-    message: str = None
+    message: str
 
 
 class AccountLockedError(SignaldException):
-    more: str = None
-    message: str = None
+    more: str
+    message: str
 
 
 class FingerprintVersionMismatchError(SignaldException):
-    message: str = None
+    message: str
 
 
 class UnknownIdentityKeyError(SignaldException):
-    message: str = None
+    message: str
 
 
 class InvalidFingerprintError(SignaldException):
-    message: str = None
+    message: str
 
 
 class InvalidGroupError(SignaldException):
-    message: str = None
+    message: str
 
 
 class GroupLinkNotActiveError(SignaldException):
-    message: str = None
+    message: str
+
+
+__all__ = [
+    "SignaldException",
+    "UntrustedIdentityError",
+    "ProtocolNoSessionError",
+    "DuplicateMessageError",
+    "ProtocolInvalidMessageError",
+    "ProtocolInvalidKeyIdError",
+    "NoSuchAccountError",
+    "ServerNotFoundError",
+    "InvalidProxyError",
+    "NoSendPermissionError",
+    "InvalidAttachmentError",
+    "InternalError",
+    "InvalidRequestError",
+    "UnknownGroupError",
+    "RateLimitError",
+    "InvalidRecipientError",
+    "AttachmentTooLargeError",
+    "AuthorizationFailedError",
+    "SQLError",
+    "ProofRequiredError",
+    "UnregisteredUserError",
+    "OwnProfileKeyDoesNotExistError",
+    "GroupPatchNotAcceptedError",
+    "GroupVerificationError",
+    "InvalidGroupStateError",
+    "InvalidInviteURIError",
+    "GroupNotActiveError",
+    "UnsupportedGroupError",
+    "InvalidBase64Error",
+    "ProfileUnavailableError",
+    "NoKnownUUIDError",
+    "NoSuchSessionError",
+    "UserAlreadyExistsError",
+    "ScanTimeoutError",
+    "CaptchaRequiredError",
+    "AccountHasNoKeysError",
+    "AccountAlreadyVerifiedError",
+    "AccountLockedError",
+    "FingerprintVersionMismatchError",
+    "UnknownIdentityKeyError",
+    "InvalidFingerprintError",
+    "InvalidGroupError",
+    "GroupLinkNotActiveError",
+]
